==> qt6-qtpositioning-6.3.1p0.tgz: lib/cmake/Qt6Positioning/Qt6QGeoPositionInfoSourceFactoryPollPluginAdditionalTargetInfo.cmake <==
# Additional target information for Qt6QGeoPositionInfoSourceFactoryPollPlugin
if(NOT DEFINED QT_DEFAULT_IMPORT_CONFIGURATION)
    set(QT_DEFAULT_IMPORT_CONFIGURATION RELEASE)
endif()
__qt_internal_promote_target_to_global_checked(Qt6::QGeoPositionInfoSourceFactoryPollPlugin)
get_target_property(_qt_imported_location Qt6::QGeoPositionInfoSourceFactoryPollPlugin IMPORTED_LOCATION_RELEASE)
get_target_property(_qt_imported_location_default Qt6::QGeoPositionInfoSourceFactoryPollPlugin IMPORTED_LOCATION_${QT_DEFAULT_IMPORT_CONFIGURATION})

# Import target "Qt6::QGeoPositionInfoSourceFactoryPollPlugin" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryPollPlugin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)

if(_qt_imported_location)
    set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryPollPlugin PROPERTY IMPORTED_LOCATION_RELWITHDEBINFO "${_qt_imported_location}")
endif()

# Import target "Qt6::QGeoPositionInfoSourceFactoryPollPlugin" for configuration "MinSizeRel"
set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryPollPlugin APPEND PROPERTY IMPORTED_CONFIGURATIONS MINSIZEREL)

if(_qt_imported_location)
    set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryPollPlugin PROPERTY IMPORTED_LOCATION_MINSIZEREL "${_qt_imported_location}")
endif()

# Default configuration
if(_qt_imported_location_default)
    set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryPollPlugin PROPERTY IMPORTED_LOCATION "${_qt_imported_location_default}")
endif()

unset(_qt_imported_location)
unset(_qt_imported_location_default)
unset(_qt_imported_soname)
unset(_qt_imported_soname_default)
unset(_qt_imported_configs)

==> qt6-qtpositioning-6.8.3.tgz: lib/cmake/Qt6Positioning/Qt6QGeoPositionInfoSourceFactoryPollPluginAdditionalTargetInfo.cmake <==
# Additional target information for Qt6QGeoPositionInfoSourceFactoryPollPlugin
if(NOT DEFINED QT_DEFAULT_IMPORT_CONFIGURATION)
    set(QT_DEFAULT_IMPORT_CONFIGURATION RELEASE)
endif()
__qt_internal_promote_target_to_global_checked(Qt6::QGeoPositionInfoSourceFactoryPollPlugin)
get_target_property(_qt_imported_location Qt6::QGeoPositionInfoSourceFactoryPollPlugin IMPORTED_LOCATION_RELEASE)
get_target_property(_qt_imported_location_default Qt6::QGeoPositionInfoSourceFactoryPollPlugin IMPORTED_LOCATION_${QT_DEFAULT_IMPORT_CONFIGURATION})

# Import target "Qt6::QGeoPositionInfoSourceFactoryPollPlugin" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryPollPlugin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)

if(_qt_imported_location)
    set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryPollPlugin PROPERTY IMPORTED_LOCATION_RELWITHDEBINFO "${_qt_imported_location}")
endif()

# Import target "Qt6::QGeoPositionInfoSourceFactoryPollPlugin" for configuration "MinSizeRel"
set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryPollPlugin APPEND PROPERTY IMPORTED_CONFIGURATIONS MINSIZEREL)

if(_qt_imported_location)
    set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryPollPlugin PROPERTY IMPORTED_LOCATION_MINSIZEREL "${_qt_imported_location}")
endif()

# Default configuration
if(_qt_imported_location_default)
    set_property(TARGET Qt6::QGeoPositionInfoSourceFactoryPollPlugin PROPERTY IMPORTED_LOCATION "${_qt_imported_location_default}")
endif()

unset(_qt_imported_location)
unset(_qt_imported_location_default)
unset(_qt_imported_soname)
unset(_qt_imported_soname_default)
unset(_qt_imported_link_dependencies)
unset(_qt_imported_link_dependencies_default)
unset(_qt_imported_objects)
unset(_qt_imported_objects_default)
unset(_qt_imported_clr)
unset(_qt_imported_clr_default)
unset(_qt_imported_configs)
